<?php
/**
 * OOPでBBS (Step2)
 *
 * オブジェクト指向プログラミングで掲示板を作ってみる。
 * ブログでその作り方を晒すために書いたものです。
 * 詳しい事は当該記事を見てください。 
 *
 *
 *           
 * PHP version 5.3
 *
 * LICENSE : このソースはCreative Commons 表示 - 非営利 2.1 日本 Licenseです。
 *           改変は自由ですが営利目的で利用することは出来ません。
 * 
 * @category  Step2
 * @package   OOPdeBBS
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 *
 */
 

/**
 * 掲示板の描画を行うクラス
 *
 * ViewはControllerに使役されるクラスです。
 * 掲示板の表示を受け持ちます。
 *
 * <step2>
 * テンプレートとメッセージのセッターを作成。
 * テンプレートファイルをincludeで読み込んで
 * コントローラーから渡されるモデルのメッセージを表示する。
 * 
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   Creative Commons BY-NC http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 */
class View {
    
    const TEMPLATE_DIRECTORY = 'template/'; //テンプレートディレクトリ名
    
    private $_template_name;      //テンプレートファイル名
    private $_systemMessage;      //システムメッセージ
    
    public function __construct()
    {
        $this->_templateName = '';
        $this->_systemMessage = '';
    }
    
    /**
     * テンプレート名のセッター
     * @param {string}  $name テンプレートファイル名
     * @return {}
     * @since 1.2 (step2)
     */
    public function setTemplateName($name)
    {
        $this->_templateName = $name.'.tpl';
    }
    
    /**
     * テンプレート名のゲッター
     * @return {string}　テンプレートファイル名
     * @since 1.2 (step2)
     */
    public function getTemplateName()
    {
       return  self::TEMPLATE_DIRECTORY . $this->_templateName;
    }
    
    /**
     * システムメッセージのセッター
     * @param {string} $text メッセージ文字列
     * @return {}
     * @since 1.2(step2)
     */
    public function setMessage($text)
    {
        $this->_systemMessage = $text;
    }
    
    /**
     * システムメッセージのゲッター
     * @return {array, string} メッセージ配列または文字列
     * @since 1.2(step2)
     */
    public function getSystemMessage()
    {
        return $this->_systemMessage;
    }
    
    /**
     * 画面に表示する
     * @return {}
     * @since 1.0 (step1)
     */
    public function display()
    {
        $message = '<p class="message">'.$this->getSystemMessage().'</p>';
        $logdata = '';
        
        include($this->getTemplateName());
    }
}

?>